==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/SecurityEventReason.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * SecurityEventReason
 */
@JsonPropertyOrder({ SecurityEventReason.JSON_PROPERTY_EN })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class SecurityEventReason implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_EN = "en";
    private String en;

    public SecurityEventReason() {
    }

    public SecurityEventReason en(String en) {

        this.en = en;
        return this;
    }

    /**
     * The event reason in English
     *
     * @return en
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(example = "Event message example", required = true, value = "The event reason in English")
    @JsonProperty(JSON_PROPERTY_EN)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getEn() {
        return en;
    }

    @JsonProperty(JSON_PROPERTY_EN)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setEn(String en) {
        this.en = en;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SecurityEventReason securityEventReason = (SecurityEventReason) o;
        return Objects.equals(this.en, securityEventReason.en);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(en);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SecurityEventReason {\n");
        sb.append("    en: ").append(toIndentedString(en)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/SecurityEventReason.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * SecurityEventReason
 */
@JsonPropertyOrder({ SecurityEventReason.JSON_PROPERTY_EN })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class SecurityEventReason implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_EN = "en";
    private String en;

    public SecurityEventReason() {
    }

    public SecurityEventReason en(String en) {

        this.en = en;
        return this;
    }

    /**
     * The event reason in English
     *
     * @return en
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(example = "Event message example", required = true, value = "The event reason in English")
    @JsonProperty(JSON_PROPERTY_EN)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getEn() {
        return en;
    }

    @JsonProperty(JSON_PROPERTY_EN)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setEn(String en) {
        this.en = en;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SecurityEventReason securityEventReason = (SecurityEventReason) o;
        return Objects.equals(this.en, securityEventReason.en);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(en);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SecurityEventReason {\n");
        sb.append("    en: ").append(toIndentedString(en)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
